RenderResult

Type Alias RenderResult 

type RenderResult = Result<Vec<(PathBuf, String)>, PathBuf>;
Successful pages or the path of a user source whose renderer panicked.

Aliased Type

enum RenderResult {
    Ok(Vec<(PathBuf, String)>),
    Err(PathBuf),
}

Variants

1.0.0

Ok(Vec<(PathBuf, String)>)

Contains the success value

1.0.0

Err(PathBuf)

Contains the error value

Layout

Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.