type RenderResult = Result<Vec<(PathBuf, String)>, PathBuf>;Expand description
Successful pages or the path of a user source whose renderer panicked.
Aliased Type
enum RenderResult {
Ok(Vec<(PathBuf, String)>),
Err(PathBuf),
}Variants
Ok(Vec<(PathBuf, String)>)
Contains the success value
Err(PathBuf)
Contains the error value
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.